@@ -5,7 +5,7 @@ from .apis import ApiBase, Contacts, Locations, Employees, Accounts, ExpenseType
     Vendors, Bills, Projects, Departments, ChargeCardAccounts, ChargeCardTransactions, Customers, Items,\
     APPayments, Reimbursements, CheckingAccounts, SavingsAccounts, Tasks, ExpensePaymentTypes, Dimensions,\
     DimensionValues, LocationEntities, ARInvoices, TaxDetails, GLDetail, Classes, JournalEntries,\
-    RevRecSchedules, RevRecScheduleEntries
+    RevRecSchedules, RevRecScheduleEntries, CostTypes
 
 
 class SageIntacctSDK:
@@ -64,6 +64,7 @@ class SageIntacctSDK:
         self.journal_entries = JournalEntries()
         self.rev_rec_schedules = RevRecSchedules()
         self.rev_rec_schedule_entries = RevRecScheduleEntries()
+        self.cost_types = CostTypes()
         self.update_sender_id()
         self.update_sender_password()
         self.update_session_id()
@@ -104,6 +105,7 @@ class SageIntacctSDK:
         self.journal_entries.set_sender_id(self.__sender_id)
         self.rev_rec_schedules.set_sender_id(self.__sender_id)
         self.rev_rec_schedule_entries.set_sender_id(self.__sender_id)
+        self.cost_types.set_sender_id(self.__sender_id)
 
     def update_sender_password(self):
         """
@@ -141,6 +143,7 @@ class SageIntacctSDK:
         self.journal_entries.set_sender_password(self.__sender_password)
         self.rev_rec_schedules.set_sender_password(self.__sender_password)
         self.rev_rec_schedule_entries.set_sender_password(self.__sender_password)
+        self.cost_types.set_sender_password(self.__sender_password)
 
     def update_session_id(self):
         """
@@ -180,3 +183,4 @@ class SageIntacctSDK:
         self.journal_entries.set_session_id(self.__session_id)
         self.rev_rec_schedules.set_session_id(self.__session_id)
         self.rev_rec_schedule_entries.set_session_id(self.__session_id)
+        self.cost_types.set_session_id(self.__session_id)
